@@ -2,5 +2,5 @@ __author__ = 'Taylor "Nekroze" Lawson'
 __email__ = 'nekroze@eturnilnetwork.com'
 
 from .sourcestring import SourceString
+from .sourcestring import SourceLine
 from .partpyerror import PartpyError
-from .matcher import Matcher
