@@ -15,23 +15,23 @@ class PartpyError(Exception):
         self.partpymsg = msg
         self.partpyobj = obj
 
-    def __str__(self):
-        output = []
-        splitlines = self.partpyobj.get_lines(1, 0).split('\n')
-        start = self.partpyobj.row - len(splitlines) + 1
-        for line in splitlines:
-            padding = 0
-            if start < 1000:
-                padding = 1
-            if start < 100:
-                padding = 2
-            if start < 10:
-                padding = 3
-            output.append(str(start) + (' ' * padding) + '|' + line)
-            start += 1
+    def __repr__(self):
+        output = [str(line) for line in \
+            self.partpyobj.get_surrounding_lines(1, 0)]
 
-        output.append(' ' * (self.partpyobj.col - 1) + '^')
+        padding = 1
+        if self.partpyobj.row < 1000:
+            padding = 2
+        if self.partpyobj.row < 100:
+            padding = 3
+        if self.partpyobj.row < 10:
+            padding = 4
+
+        output.append(' ' * (self.partpyobj.col + padding + 1) + '^' + '\n')
         if self.partpymsg:
             output.append(self.partpymsg)
 
-        return '\n'.join(output)
+        return ''.join(output)
+
+    def __str__(self):
+        return self.__repr__()
